@@ -251,6 +251,11 @@ def configure_logging(verbose: bool) -> None:
     type=float,
     help="Specify the percentage of tasks that need to be successful.",
 )
+@click.option(
+    "--fail-threshold",
+    type=float,
+    help="Specify the percentage of tasks that need to be failed.",
+)
 @click.option(
     "--evg-config-file",
     default=DEFAULT_EVG_CONFIG,
@@ -282,8 +287,8 @@ def configure_logging(verbose: bool) -> None:
 @click.option(
     "--git-operation",
     type=click.Choice([a.value for a in GitAction]),
-    default=GitAction.CHECKOUT,
-    help="Git operations to perform with found commit [default=checkout].",
+    default=GitAction.NONE,
+    help="Git operations to perform with found commit [default=none].",
 )
 @click.option("-b", "--branch", help="Name of branch to create on checkout.")
 @click.option(
@@ -318,6 +323,7 @@ def main(
     run_task: List[str],
     run_threshold: float,
     pass_threshold: float,
+    fail_threshold: float,
     evg_config_file: str,
     evg_project: str,
     build_variant: List[str],
@@ -337,27 +343,28 @@ def main(
     verbose: bool,
 ) -> None:
     """
-    Find and checkout a recent git commit that matches the specified criteria.
+    Find and perform git actions on a recent commit that matches the specified criteria.
 
     When running an Evergreen patch build, it can be useful that base your changes on a commit
     in which the tests in Evergreen have already been run. This way if you encounter any failures
     in your patch build, you can easily compare the failure with what was seen in the base commit
     to understand if your changes may have introduced the failure.
 
-    This command allows you to specify criteria to use to find and checkout a git commit to
+    This command allows you to specify criteria to use to find a git commit to
     start work from.
 
     Criteria
 
-    There are 4 criteria that can be specified:
+    There are 5 criteria that can be specified:
 
     * The percentage of tasks that have passed in each build.\n
+    * The percentage of tasks that have failed in each build.\n
     * The percentage of tasks that have run in each build.\n
     * Specific tasks that must have passed in each build (if they are part of that build).\n
     * Specific tasks that must have run in each build (if they are part of that build).\n
 
     If no criteria are specified, a success threshold of 0.95 will be used and
-    the other 3 above options will be null.
+    the other 4 above options will be null.
 
     Additionally, you can specify which build variants the criteria should be checked against. By
     default, only builds that end in 'required' will be checked.
@@ -406,6 +413,9 @@ def main(
     if pass_threshold is not None:
         build_checks.success_threshold = pass_threshold
 
+    if fail_threshold is not None:
+        build_checks.failure_threshold = fail_threshold
+
     if run_threshold is not None:
         build_checks.run_threshold = run_threshold
 
@@ -416,7 +426,7 @@ def main(
         build_checks.active_tasks = set(run_task)
 
     # If no criteria were specified, use the default.
-    if not any([pass_threshold, run_threshold, passing_task, run_task]):
+    if not any([pass_threshold, fail_threshold, run_threshold, passing_task, run_task]):
         build_checks.success_threshold = DEFAULT_THRESHOLD
 
     def dependencies(binder: inject.Binder) -> None:
